@@ -1,7 +1,7 @@
 /*
  * irc-info.c - info, infolist and hdata hooks for IRC plugin
  *
- * Copyright (C) 2003-2023 Sébastien Helleu <flashcode@flashtux.org>
+ * Copyright (C) 2003-2024 Sébastien Helleu <flashcode@flashtux.org>
  *
  * This file is part of WeeChat, the extensible chat client.
  *
@@ -197,10 +197,6 @@ irc_info_info_irc_nick_color_cb (const void *pointer, void *data,
                                  const char *info_name,
                                  const char *arguments)
 {
-    char *pos_comma, *server;
-    const char *pos_nick;
-    struct t_irc_server *ptr_server;
-
     /* make C compiler happy */
     (void) pointer;
     (void) data;
@@ -209,21 +205,7 @@ irc_info_info_irc_nick_color_cb (const void *pointer, void *data,
     if (!arguments || !arguments[0])
         return NULL;
 
-    ptr_server = NULL;
-    pos_nick = arguments;
-    pos_comma = strchr (arguments, ',');
-    if (pos_comma)
-    {
-        pos_nick = pos_comma + 1;
-        server = weechat_strndup (arguments, pos_comma - arguments);
-        if (server)
-        {
-            ptr_server = irc_server_search (server);
-            free (server);
-        }
-    }
-
-    return irc_nick_find_color (ptr_server, pos_nick);
+    return irc_nick_find_color (arguments);
 }
 
 /*
@@ -235,10 +217,6 @@ irc_info_info_irc_nick_color_name_cb (const void *pointer, void *data,
                                       const char *info_name,
                                       const char *arguments)
 {
-    char *pos_comma, *server;
-    const char *pos_nick;
-    struct t_irc_server *ptr_server;
-
     /* make C compiler happy */
     (void) pointer;
     (void) data;
@@ -247,21 +225,7 @@ irc_info_info_irc_nick_color_name_cb (const void *pointer, void *data,
     if (!arguments || !arguments[0])
         return NULL;
 
-    ptr_server = NULL;
-    pos_nick = arguments;
-    pos_comma = strchr (arguments, ',');
-    if (pos_comma)
-    {
-        pos_nick = pos_comma + 1;
-        server = weechat_strndup (arguments, pos_comma - arguments);
-        if (server)
-        {
-            ptr_server = irc_server_search (server);
-            free (server);
-        }
-    }
-
-    return irc_nick_find_color_name (ptr_server, pos_nick);
+    return irc_nick_find_color_name (arguments);
 }
 
 /*
@@ -380,6 +344,9 @@ irc_info_info_irc_server_isupport_cb (const void *pointer, void *data,
     (void) data;
     (void) info_name;
 
+    if (!arguments || !arguments[0])
+        return NULL;
+
     isupport_value = NULL;
     pos_comma = strchr (arguments, ',');
     if (pos_comma)
@@ -418,6 +385,9 @@ irc_info_info_irc_server_isupport_value_cb (const void *pointer, void *data,
     (void) data;
     (void) info_name;
 
+    if (!arguments || !arguments[0])
+        return NULL;
+
     isupport_value = NULL;
     pos_comma = strchr (arguments, ',');
     if (pos_comma)
@@ -456,6 +426,9 @@ irc_info_info_irc_server_cap_cb (const void *pointer, void *data,
     (void) data;
     (void) info_name;
 
+    if (!arguments || !arguments[0])
+        return NULL;
+
     has_cap = 0;
     pos_comma = strchr (arguments, ',');
     if (pos_comma)
@@ -494,6 +467,9 @@ irc_info_info_irc_server_cap_value_cb (const void *pointer, void *data,
     (void) data;
     (void) info_name;
 
+    if (!arguments || !arguments[0])
+        return NULL;
+
     cap_value = NULL;
     pos_comma = strchr (arguments, ',');
     if (pos_comma)
@@ -1259,19 +1235,15 @@ irc_info_init ()
         &irc_info_info_irc_nick_from_host_cb, NULL, NULL);
     weechat_hook_info (
         "irc_nick_color",
-        N_("get nick color code, ignoring case (this calls the info "
-           "\"nick_color_ignore_case\" with appropriate range, according "
-           "to the value of CASEMAPPING on the server, "
-           "defaulting to \"rfc1459\" if the server is not given)"),
-        N_("server,nickname (server is optional)"),
+        N_("get nick color code "
+           "(*deprecated* since version 1.5, replaced by \"nick_color\")"),
+        N_("nickname"),
         &irc_info_info_irc_nick_color_cb, NULL, NULL);
     weechat_hook_info (
         "irc_nick_color_name",
-        N_("get nick color name, ignoring case (this calls the info "
-           "\"nick_color_name_ignore_case\" with appropriate range, according "
-           "to the value of CASEMAPPING on the server, "
-           "defaulting to \"rfc1459\" if the server is not given)"),
-        N_("server,nickname (server is optional)"),
+        N_("get nick color name "
+           "(*deprecated* since version 1.5, replaced by \"nick_color_name\")"),
+        N_("nickname"),
         &irc_info_info_irc_nick_color_name_cb, NULL, NULL);
     weechat_hook_info (
         "irc_buffer",
@@ -1302,7 +1274,7 @@ irc_info_init ()
         "irc_is_message_ignored",
         N_("1 if the nick is ignored (message is not displayed)"),
         N_("server,message (message is the raw IRC message)"),
-        &irc_info_info_irc_is_channel_cb, NULL, NULL);
+        &irc_info_info_irc_is_message_ignored_cb, NULL, NULL);
 
     /* info_hashtable hooks */
     weechat_hook_info_hashtable (
